from sqlalchemy import Column
from sqlalchemy import Integer
from sqlalchemy import String
from sqlalchemy import orm
from vortex.Tuple import Tuple
from vortex.Tuple import addTupleType

from peek_plugin_docdb_generic_menu._private.PluginNames import (
    docDbGenericMenuTuplePrefix,
)
from peek_plugin_docdb_generic_menu._private.storage.DeclarativeBase import (
    DeclarativeBase,
)


@addTupleType
class DocDbGenericMenuTuple(DeclarativeBase, Tuple):
    __tupleType__ = docDbGenericMenuTuplePrefix + "DocDbGenericMenuTuple"
    __tablename__ = "Menu"

    id = Column(Integer, primary_key=True, autoincrement=True)
    modelSetKey = Column(String)
    coordSetKey = Column(String)
    faIcon = Column(String)
    title = Column(String)
    tooltip = Column(String)
    url = Column(String, nullable=False)
    showCondition = Column(String, nullable=True)

    @orm.reconstructor
    def __init__(self, **kwargs):
        Tuple.__init__(self, **kwargs)



from peek_plugin_base.PeekVortexUtil import peekServerName
from peek_plugin_docdb_generic_menu._private.PluginNames import (
    docDbGenericMenuFilt,
)
from peek_plugin_docdb_generic_menu._private.PluginNames import (
    docDbGenericMenuObservableName,
)
from vortex.handler.TupleDataObservableProxyHandler import (
    TupleDataObservableProxyHandler,
)


def makeDeviceTupleDataObservableProxy():
    return TupleDataObservableProxyHandler(
        observableName=docDbGenericMenuObservableName,
        proxyToVortexName=peekServerName,
        additionalFilt=docDbGenericMenuFilt,
    )



"""rename diagram to object

Peek Plugin Database Migration Script

Revision ID: 9e52cf449784
Revises: bac1e4f7a3d9
Create Date: 2019-07-28 14:35:58.718257

"""

# revision identifiers, used by Alembic.
revision = "9e52cf449784"
down_revision = "bac1e4f7a3d9"
branch_labels = None
depends_on = None

from alembic import op
from sqlalchemy import text


def upgrade():
    renameToDocDbSql = text(
        """
            DO $$
            BEGIN
                IF EXISTS(
                    SELECT table_schema
                      FROM information_schema.tables
                      WHERE table_schema = 'pl_docdb_generic_menu'
                        AND table_name = 'DiagramGenericMenu'
                  )
                THEN
                  EXECUTE ' ALTER TABLE pl_docdb_generic_menu."DiagramGenericMenu" 
                            RENAME TO "Menu" ';
                END IF;
            END
            $$;
        """
    )
    op.execute(renameToDocDbSql)


def downgrade():
    op.rename_table(
        "Menu", "DiagramGenericMenu", schema="pl_docdb_generic_menu"
    )



"""initial

Peek Plugin Database Migration Script

Revision ID: 1f288982a4e2
Revises: 
Create Date: 2017-10-05 10:28:00.029716

"""

# revision identifiers, used by Alembic.
revision = "1f288982a4e2"
down_revision = None
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "GenericDiagramMenu",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("modelSetKey", sa.String(), nullable=True),
        sa.Column("coordSetKey", sa.String(), nullable=True),
        sa.Column("faIcon", sa.String(), nullable=True),
        sa.Column("title", sa.String(), nullable=False),
        sa.Column("url", sa.String(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        schema="pl_docdb_generic_menu",
    )
    op.create_table(
        "Setting",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
        schema="pl_docdb_generic_menu",
    )
    op.create_table(
        "SettingProperty",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("settingId", sa.Integer(), nullable=False),
        sa.Column("key", sa.String(length=50), nullable=False),
        sa.Column("type", sa.String(length=16), nullable=True),
        sa.Column("int_value", sa.Integer(), nullable=True),
        sa.Column("char_value", sa.String(), nullable=True),
        sa.Column("boolean_value", sa.Boolean(), nullable=True),
        sa.ForeignKeyConstraint(
            ["settingId"],
            ["pl_docdb_generic_menu.Setting.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
        schema="pl_docdb_generic_menu",
    )
    op.create_index(
        "idx_SettingProperty_settingId",
        "SettingProperty",
        ["settingId"],
        unique=False,
        schema="pl_docdb_generic_menu",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "idx_SettingProperty_settingId",
        table_name="SettingProperty",
        schema="pl_docdb_generic_menu",
    )
    op.drop_table("SettingProperty", schema="pl_docdb_generic_menu")
    op.drop_table("Setting", schema="pl_docdb_generic_menu")
    op.drop_table("GenericDiagramMenu", schema="pl_docdb_generic_menu")
    # ### end Alembic commands ###
